@@ -6,7 +6,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.2 2007/09/02 14:40:34 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.3 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Example2_Index extends AppAction
@@ -32,7 +32,7 @@ class Example2_Index extends AppAction
     {
         // ե
         // ¥եϡexamples/webapp/lib/Example2Form.php
-        $form =& $this->getActionForm($data, 'Example2Form');
+        $form =& $this->getActionForm($data, 'Example2Form', !$context->isPost());
         if ($context->isPost()) {
             // ϤΥݥȥХå
             if ($form->validate()) {
