@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.6 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.7 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.6 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.7 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowDel extends SyL_AdmFlow
@@ -84,7 +84,7 @@ class SyL_AdmFlowDel extends SyL_AdmFlow
             // ѥ᡼
             $keys = $data->geta($key_name);
             // ѥ᡼å
-            if (!$keys) {
+            if (!is_array($keys) || (count($keys) == 0)) {
                 SyL_Response::redirect($this->getUrl('lst'));
             }
 
@@ -99,17 +99,16 @@ class SyL_AdmFlowDel extends SyL_AdmFlow
                 // Բ
                 SyL_Response::redirect($this->getUrl('lst'));
             }
-            // ȥ󥶥󳫻
-            $conn->beginTransaction();
             // ¹
-            $this->delete($adm);
-            // ȥ󥶥
-            $conn->commit();
+            if (!$this->delete($adm)) {
+                $this->closeDB($conn);
+                trigger_error("[Adm error] Can't Delete Opperation", E_USER_ERROR);
+            }
             // DB³λ
             $this->closeDB($conn);
 
             // λ̤إ쥯
-            SyL_Response::redirect($this->getUrl('fin') . '?adm_action=del');
+            SyL_Response::redirect($this->getUrl('fin') . '?adm_action=del&adm_u=' . urlencode($data->get('adm_u')));
         } else {
             SyL_Response::redirect($this->getUrl('lst'));
         }
@@ -123,7 +122,7 @@ class SyL_AdmFlowDel extends SyL_AdmFlow
      */
     function delete(&$adm)
     {
-        $adm->delete();
+        return $adm->delete();
     }
 }
 
