@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.7 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.8 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.7 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.8 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowLst extends SyL_AdmFlow
@@ -215,8 +215,6 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
         $data->set('url_upd', $this->getUrl('upd'));
         $data->set('url_vew', $this->getUrl('vew'));
         $data->set('url_del', $this->getUrl('del'));
-        $data->set('url_up',  $this->getUpUrl());
-        $data->set('url_script', $this->getScriptName());
         $data->set('url_dir', dirname($this->getScriptName()));
 
         // ʸϢ
