@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.5 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.6 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.5 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.6 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowNew extends SyL_AdmFlow
@@ -90,6 +90,20 @@ class SyL_AdmFlowNew extends SyL_AdmFlow
             SyL_Response::redirect($this->getUrl('lst'));
         }
 
+        // ɽΤ
+        $read_only = '';
+        if (!$data->get('adm_action_exe')) {
+            $read_only = $data->get('adm_read_only');
+            if ($read_only) {
+                foreach (explode("\t", $read_only) as $column) {
+                    $form->setReadOnlyColumn($column);
+                }
+            }
+        }
+
+        // Ϣǡ󥯤ѥ
+        list($pu, $cu, $nu) = $this->getLocations($data->get('adm_u'));
+
         // ǡ֥ȥå
         $form->registerInput($data);
         // ե๽
@@ -110,7 +124,7 @@ class SyL_AdmFlowNew extends SyL_AdmFlow
                     // Ͽ¹
                     $this->insert($adm);
                     // λ̤إ쥯
-                    SyL_Response::redirect($this->getUrl('fin') . '?adm_action=new');
+                    SyL_Response::redirect($this->getUrl('fin') . '?adm_action=new&adm_u=' . urlencode($data->get('adm_u')));
                 }
             } else if ($data->get('adm_action_prev')) {
                 // ǧ̤
@@ -123,13 +137,11 @@ class SyL_AdmFlowNew extends SyL_AdmFlow
         $this->closeDB($conn);
 
         // եǥǡ
-        $data->set('form', $form->getResultArray());
+        $data->set('form',      $form->getResultArray());
+        $data->set('read_only', $read_only);
         // ǧɽϢ
         $data->set('view_alert',   $form->getStructConfig('view_alert'));
         $data->set('view_confirm', $form->getStructConfig('view_confirm'));
-        // ɽѥѥ᡼Ѥ
-        $data->set('page', $data->get('page'));
-        $data->set('sort', $data->get('sort'));
 
         // ʸϢ
         $data->set('title', $form->getStructConfig('title'));
@@ -137,8 +149,12 @@ class SyL_AdmFlowNew extends SyL_AdmFlow
         // URL
         $data->set('url_lst', $this->getUrl('lst'));
         $data->set('url_new', $this->getUrl('new'));
-        $data->set('url_up',  $this->getUpUrl());
         $data->set('url_dir', dirname($this->getScriptName()));
+        $data->set('url_lst_u', $this->getUrl('lst', $pu));
+
+        // Ϣǡ󥯤ѥ
+        $data->set('cu',  $cu);
+        $data->set('cuu', $data->get('adm_u'));
     }
 
     /**
