@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowUpd.php,v 1.5 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowUpd.php,v 1.6 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowUpd.php,v 1.5 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowUpd.php,v 1.6 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowUpd extends SyL_AdmFlow
@@ -99,6 +99,20 @@ class SyL_AdmFlowUpd extends SyL_AdmFlow
             SyL_Response::redirect($this->getUrl('lst'));
         }
 
+        // ɽΤ
+        $read_only = '';
+        if (!$data->get('adm_action_exe')) {
+            $read_only = $data->get('adm_read_only');
+            if ($read_only) {
+                foreach (explode("\t", $read_only) as $column) {
+                    $form->setReadOnlyColumn($column);
+                }
+            }
+        }
+
+        // Ϣǡ󥯤ѥ
+        list($pu, $cu, $nu) = $this->getLocations($data->get('adm_u'));
+
         // ʬ
         if ($context->isPost()) {
             // ǡ֥ȥå
@@ -117,9 +131,11 @@ class SyL_AdmFlowUpd extends SyL_AdmFlow
                 // Хǡ¹
                 if ($this->validate($adm)) {
                     // ¹
-                    $this->update($adm);
+                    if (!$this->update($adm)) {
+                        trigger_error("[Adm error] Can't Update Opperation", E_USER_ERROR);
+                    }
                     // λ̤إ쥯
-                    SyL_Response::redirect($this->getUrl('fin') . '?adm_action=upd');
+                    SyL_Response::redirect($this->getUrl('fin') . '?adm_action=upd&adm_u=' . urlencode($data->get('adm_u')));
                 }
             } else if ($data->get('adm_action_prev')) {
                 // ǧ̤
@@ -145,16 +161,14 @@ class SyL_AdmFlowUpd extends SyL_AdmFlow
         $this->closeDB($conn);
 
         // եǥǡ
-        $data->set('form', $form->getResultArray());
+        $data->set('form',      $form->getResultArray());
+        $data->set('read_only', $read_only);
         // 祭ѥ᡼
         $data->set('key_name',  $key_name);
         $data->set('key_value', $key_value);
         // ǧɽϢ
         $data->set('view_alert',   $form->getStructConfig('view_alert'));
         $data->set('view_confirm', $form->getStructConfig('view_confirm'));
-        // ɽѥѥ᡼Ѥ
-        $data->set('page', $data->get('page'));
-        $data->set('sort', $data->get('sort'));
 
         // ʸϢ
         $data->set('title', $form->getStructConfig('title'));
@@ -162,8 +176,12 @@ class SyL_AdmFlowUpd extends SyL_AdmFlow
         // URL
         $data->set('url_lst', $this->getUrl('lst'));
         $data->set('url_upd', $this->getUrl('upd'));
-        $data->set('url_up',  $this->getUpUrl());
         $data->set('url_dir', dirname($this->getScriptName()));
+        $data->set('url_lst_u', $this->getUrl('lst', $pu));
+
+        // Ϣǡ󥯤ѥ
+        $data->set('cu',  $cu);
+        $data->set('cuu', $data->get('adm_u'));
     }
 
     /**
@@ -186,7 +204,7 @@ class SyL_AdmFlowUpd extends SyL_AdmFlow
      */
     function update(&$adm)
     {
-        $adm->update();
+        return $adm->update();
     }
 }
 
