@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowVew.php,v 1.4 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowVew.php,v 1.5 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowVew.php,v 1.4 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowVew.php,v 1.5 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowVew extends SyL_AdmFlow
@@ -117,17 +117,10 @@ class SyL_AdmFlowVew extends SyL_AdmFlow
 
         // DB³λ
         $this->closeDB($conn);
-/*
-        $pu = '';
-        $nu = urlencode($context->getRequestUri());
-        $cu = $data->geta('cu');
-        if (is_array($cu) && (count($cu) > 0)) {
-            $pu = array_pop($cu);
-            $cu = array_map('urlencode', $cu);
-        } else {
-            $cu = array();
-        }
-*/
+
+        // Ϣǡ󥯤ѥ
+        list($pu, $cu, $nu) = $this->getLocations($data->get('adm_u') , $key_name . '=' . urlencode($key));
+
         // եǥǡ
         $data->set('form', $form->getResultArray());
         // 祭ѥ᡼
@@ -135,10 +128,6 @@ class SyL_AdmFlowVew extends SyL_AdmFlow
         $data->set('key_value', $key_value);
         $data->set('key_array', $adm->getKey());
 
-        // ɽѥѥ᡼Ѥ
-        $data->set('page', $data->get('page'));
-        $data->set('sort', $data->get('sort'));
-
         // ǧɽϢ
         $data->set('view_alert', $form->getStructConfig('view_alert'));
         // ʸϢ
@@ -148,13 +137,13 @@ class SyL_AdmFlowVew extends SyL_AdmFlow
         $data->set('url_lst', $this->getUrl('lst'));
         $data->set('url_upd', $this->getUrl('upd'));
         $data->set('url_del', $this->getUrl('del'));
-        $data->set('url_up',  $this->getUpUrl());
         $data->set('url_dir', dirname($this->getScriptName()));
-/*
+        $data->set('url_lst_u', $this->getUrl('lst', $pu));
+
         $data->set('pu', $pu);
-        $data->set('nu', $nu);
         $data->set('cu', $cu);
-*/
+        $data->set('nu', $nu);
+
         // Խǽե饰
         $data->set('enable_upd', $adm->isUpd());
         // ǽե饰
