@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmActionForm.php,v 1.2 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmActionForm.php,v 1.3 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_ActionForm.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmActionForm.php,v 1.2 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmActionForm.php,v 1.3 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmActionForm extends SyL_ActionForm
@@ -114,7 +114,7 @@ class SyL_AdmActionForm extends SyL_ActionForm
         case 'del': $this->type = 'del'; break; // 
         case 'vew': $this->type = 'vew'; break; // ܺɽ
         case 'fin': $this->type = 'fin'; break; // λɽ
-        default: trigger_error("[SyL error] Invalid type ({$type})", E_USER_ERROR);
+        default: trigger_error("[Adm error] Invalid type ({$type})", E_USER_ERROR);
         }
     }
 
@@ -184,6 +184,22 @@ class SyL_AdmActionForm extends SyL_ActionForm
         return $this->maintenance_table;
     }
 
+    /**
+     * ɽΤǤѹ
+     *
+     * @access public
+     * @return string ̾
+     */
+    function setReadOnlyColumn($column)
+    {
+        if (isset($this->elements_config[$column])) {
+            switch ($this->type) {
+            case 'new': $this->elements_config[$column]['read_only_new'] = true; break;
+            case 'upd': $this->elements_config[$column]['read_only_upd'] = true; break;
+            }
+        }
+    }
+
     /**
      * եۤ
      *
@@ -462,9 +478,9 @@ class SyL_AdmActionForm extends SyL_ActionForm
     function getDataSources()
     {
         $result = array();
-        foreach ($this->elements_config as $name => $elements_config) {
-            if (isset($elements_config['data_source']) && $elements_config['data_source']) {
-                $result[$name] = $elements_config['data_source'];
+        foreach ($this->getListColumns() as $name) {
+            if (isset($this->elements_config[$name]['data_source']) && $this->elements_config[$name]['data_source']) {
+                $result[$name] = $this->elements_config[$name]['data_source'];
             }
         }
         return $result;
