@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlow.php,v 1.6 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlow.php,v 1.7 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -52,7 +52,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Adm.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlow.php,v 1.6 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlow.php,v 1.7 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlow extends AppAction
@@ -159,31 +159,47 @@ class SyL_AdmFlow extends AppAction
      * ڥ졼URL
      *
      * @access protected
-     * @return string ڥ졼̾
+     * @param string ڥ졼̾
+     * @param string PATH_INFO
+     * @return string ڥ졼URL
      */
-    function getUrl($opp_name='')
+    function getUrl($opp_name='', $pu='')
     {
         if (!$opp_name) {
             $opp_name = $this->opp_name;
         }
-        return "{$this->script_name}{$this->pathinfo_base}{$opp_name}" . SYL_ROUTER_URL_EXT;
+        if ($pu) {
+            return "{$this->script_name}{$pu}";
+        } else {
+            return "{$this->script_name}{$this->pathinfo_base}{$opp_name}" . SYL_ROUTER_URL_EXT;
+        }
     }
 
     /**
-     * ̳ؤURL
+     * Ϣǡ 󥯤
      *
      * @access protected
-     * @return string ̳ؤURL
+     * @param string Ϣǡ
+     * @return array Ϣǡ󥯡PREV, CURRENT, NEXT
      */
-    function getUpUrl()
+    function getLocations($u, $key='')
     {
-        $pathinfo_base = dirname($this->pathinfo_base);
-        if (($pathinfo_base == '/') || ($pathinfo_base == '\\')) {
-            $pathinfo_base = '';
+        $pu = '';
+        $cu = ($u ? $u : '');
+        $nu = '';
+        if ($cu) {
+            if ($key) {
+                $nu = $cu . "\t" . $this->pathinfo_base .'vew' . SYL_ROUTER_URL_EXT . '?' . $key;
+            }
+            $cus = explode("\t", $cu);
+            $pu  = array_pop($cus);
+            $cu  = implode("\t", $cus);
         } else {
-            $pathinfo_base .= '/';
+            if ($key) {
+                $nu = $this->pathinfo_base .'vew' . SYL_ROUTER_URL_EXT . '?' . $key;
+            }
         }
-        return "{$this->script_name}{$pathinfo_base}";
+        return array($pu, $cu, $nu);
     }
 }
 
