@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AuthBasic.php,v 1.6 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AuthBasic.php,v 1.7 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AuthBasic.php,v 1.6 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AuthBasic.php,v 1.7 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AuthBasic extends SyL_Auth
@@ -67,10 +67,10 @@ class SyL_AuthBasic extends SyL_Auth
 
         // ѥ᡼Ƚ
         if (isset($_SERVER['PHP_AUTH_USER']) && ($_SERVER['PHP_AUTH_USER'] !== '')) {
-            SyL_Loggers::info("[Auth] Login Action: true");
+            SyL_Loggers::info("Login Action: true");
             return true;
         } else {
-            SyL_Loggers::info("[Auth] Login Action: false");
+            SyL_Loggers::info("Login Action: false");
         }
 
         // ١åǧɽ
