@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorJs.php,v 1.6 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorJs.php,v 1.7 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorJs.php,v 1.6 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorJs.php,v 1.7 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorJs extends SyL_Error
@@ -68,6 +68,24 @@ class SyL_ErrorJs extends SyL_Error
         $response->display($error_message);
     }
 
+    /**
+     * ¸¾
+     *
+     * @access protected
+     * @return string ¾
+     */
+    function extraLog()
+    {
+        $error_message  = '';
+        if (isset($_SERVER['REQUEST_METHOD']))  $error_message .= 'REQUEST_METHOD: ' . $_SERVER['REQUEST_METHOD']  . $this->eol;
+        if (isset($_SERVER['REQUEST_URI']))     $error_message .= 'REQUEST_URI: '    . $_SERVER['REQUEST_URI']     . $this->eol;
+        if (isset($_SERVER['HTTP_REFERER']))    $error_message .= 'REFERRER: '       . $_SERVER['HTTP_REFERER']    . $this->eol;
+        if (isset($_SERVER['HTTP_USER_AGENT'])) $error_message .= 'USER_AGENT: '     . $_SERVER['HTTP_USER_AGENT'] . $this->eol;
+        $error_message .= 'GET : '  . print_r($_GET, true);
+        $error_message .= 'POST : ' . print_r($_POST, true);
+        return $error_message;
+    }
+
 }
 
 ?>
