@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestSessionDb.php,v 1.2 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestSessionDb.php,v 1.3 2007/06/05 13:08:24 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -59,7 +59,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_DB.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestSessionDb.php,v 1.2 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestSessionDb.php,v 1.3 2007/06/05 13:08:24 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RequestSessionDb extends SyL_RequestSession
@@ -159,7 +159,7 @@ class SyL_RequestSessionDb extends SyL_RequestSession
         if (SYL_SESSION_SAVE_PATH) {
             $this->conn =& SyL_DB::getConnection(SYL_SESSION_SAVE_PATH);
         } else {
-            $this->conn =& SyL_DB::getConnection(SYL_DB_DSN_SESSION);
+            $this->conn =& SyL_DB::getConnection(SYL_DB_DSN);
         }
         return is_object($this->conn);
     }
