@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.23 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.24 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.23 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.24 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
@@ -499,7 +499,7 @@ echo "</pre>";
     function log($type, $message)
     {
         if ($this->isComponent('log')) {
-            SyL_Loggers::$type("[Container] " . $message);
+            SyL_Loggers::$type($message);
         }
     }
 }
