@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.12 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.13 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loader.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.12 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.13 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Context
@@ -248,11 +248,11 @@ class SyL_Context
         }
 
         // ǥХå - ƥץ졼Ȥξ
-        SyL_Loggers::debug("[Context] Template dir: {$template_dir} file: {$template_file}");
+        SyL_Loggers::debug("Template dir: {$template_dir} file: {$template_file}");
 
         // ƥץ졼ȥե¸ߥå
         if ($trigger_error_404 && !is_file($template_dir . $template_file)) {
-            SyL_Loggers::warn("[Context] Template file not found dir: {$template_dir} file: {$template_file}");
+            SyL_Loggers::warn("Template file not found dir: {$template_dir} file: {$template_file}");
             SyL_Response::forward404();
         }
         return $template_file;
