@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.29 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.30 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -69,7 +69,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.29 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.30 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -319,12 +319,12 @@ class SyL_Controller
         // ꥯȽ
         if (SYL_ENV_TYPE == 'cmd') {
             $script_file = isset($_SERVER['SCRIPT_FILENAME']) ? $_SERVER['SCRIPT_FILENAME'] : '';
-            SyL_Loggers::info("[Controller] cmd start: {$script_file}");
+            SyL_Loggers::info("cmd start: {$script_file}");
         } else {
             $method = isset($_SERVER['REQUEST_METHOD']) ? $_SERVER['REQUEST_METHOD'] : '';
             $addr   = isset($_SERVER['REMOTE_ADDR'])    ? $_SERVER['REMOTE_ADDR']    : '';
             $uri    = isset($_SERVER['REQUEST_URI'])    ? $_SERVER['REQUEST_URI']    : '';
-            SyL_Loggers::info("[Controller] request start: \"{$method}: {$uri}\" - {$addr}");
+            SyL_Loggers::info("request start: \"{$method}: {$uri}\" - {$addr}");
         }
     }
 
@@ -409,7 +409,7 @@ class SyL_Controller
     {
         // ̥ǥХå
         if (function_exists('memory_get_usage') && class_exists('SyL_Loggers')) {
-            $debug = '[Controller] Memory Status  current: ' . number_format(floor(memory_get_usage()/1024)) . 'KB';
+            $debug = 'Memory Status  current: ' . number_format(floor(memory_get_usage()/1024)) . 'KB';
             if (function_exists('memory_get_peak_usage')) {
                 $debug .= ' max: ' . number_format(floor(memory_get_peak_usage()/1024)) . 'KB';
             }
@@ -446,9 +446,12 @@ class SyL_Controller
     {
         static $num = 1;
         // ߤΥ顼٥뤫饨顼̤ɽ뤫Ƚ
-        if (func_get_arg(0) & error_reporting()) {
+        if ((func_get_arg(0) & error_reporting()) &&
+            (func_get_arg(0) != E_USER_NOTICE)) {
             if ($num++ > 1) {
-                echo "[SyL error] Error handler trigger 2";
+                $error_message = "[SyL error] Error handler trigger 2";
+                SyL_Loggers::warn($error_message);
+                echo $error_message;
                 exit;
             }
 
@@ -477,7 +480,7 @@ class SyL_Controller
             exit;
         } else {
             $error_message = "[SyL_error] Background logging out of error_reporting. level: " . func_get_arg(0) . " message: " . func_get_arg(1) . " file: " . func_get_arg(2) . " line: " . func_get_arg(3);
-            SyL_Loggers::info($error_message);
+            SyL_Loggers::notice($error_message);
         }
     }
 
