@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.25 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.26 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.25 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.26 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -234,7 +234,7 @@ class SyL_Error
      *   E_USER_NOTICE
      * Τ
      *
-     * @access public
+     * @access protected
      * @param  int    顼No
      * @return string 顼̾
      */
@@ -267,7 +267,7 @@ class SyL_Error
     /**
      * ȥ졼
      *
-     * @access public
+     * @access private
      * @return array ȥ졼
      */
     function getTrace()
@@ -305,17 +305,12 @@ class SyL_Error
      */
     function getErrorMessageTrace()
     {
-        $error_message = '[' . $this->getErrorType() . '] ' . implode($this->eol, $this->getErrorMessages()) . $this->eol;
+        $error_message = implode($this->eol, $this->getErrorMessages()) . $this->eol;
         foreach ($this->getTrace() as $values) {
             $error_message .= "[file] "     . $values['file']     . " ";
             $error_message .= "[line] "     . $values['line']     . " ";
             $error_message .= "[function] " . $values['function'] . $this->eol;
         }
-        if (isset($_SERVER['REQUEST_METHOD']))  $error_message .= 'REQUEST_METHOD: '  . $_SERVER['REQUEST_METHOD']  . $this->eol;
-        if (isset($_SERVER['REQUEST_URI']))     $error_message .= 'REQUEST_URI: '     . $_SERVER['REQUEST_URI']     . $this->eol;
-        if (isset($_SERVER['HTTP_REFERER']))    $error_message .= 'REFERRER: '        . $_SERVER['HTTP_REFERER']    . $this->eol;
-        if (isset($_SERVER['HTTP_USER_AGENT'])) $error_message .= 'USER_AGENT: '      . $_SERVER['HTTP_USER_AGENT'] . $this->eol;
-
         return $error_message;
     }
 
@@ -342,7 +337,7 @@ class SyL_Error
     }
 
     /**
-     * 󥰤¸
+     * ¸
      *
      * @access public
      */
@@ -350,8 +345,7 @@ class SyL_Error
     {
         // ȥ졼դ顼å
         $error_message  = $this->getErrorMessageTrace();
-        $error_message .= 'GET : '  . print_r($_GET, true);
-        $error_message .= 'POST : ' . print_r($_POST, true);
+        $error_message .= $this->extraLog();
 
         // 顼٥˥¸
         switch ($this->controller->getErrorNo()) {
@@ -370,6 +364,17 @@ class SyL_Error
         }
     }
 
+    /**
+     * ¸¾
+     *
+     * @access protected
+     * @return string ¾
+     */
+    function extraLog()
+    {
+        return '';
+    }
+
     /**
      * 顼᡼
      *
@@ -414,7 +419,7 @@ EOF;
             $mail->addTo(SYL_MAIL_ADMIN_ADDRESS);
             $mail->setBody($error_mail_body);
             if (!$mail->send()) {
-                SyL_Loggers::error($mail->getErrorMessage());
+                SyL_Loggers::error("Error mail send error\n" . $mail->getErrorMessage());
             }
         }
     }
