@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_User.php,v 1.2 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_User.php,v 1.3 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_User.php,v 1.2 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_User.php,v 1.3 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_User
@@ -66,6 +66,15 @@ class SyL_User
      */
     var $password_parameter_name = 'login_password';
 
+    /**
+     * 󥹥ȥ饯
+     * 
+     * @access public
+     */
+    function SyL_User()
+    {
+    }
+
     /**
      * 桼ID򥻥å
      * 
