@@ -35,7 +35,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDao.php,v 1.7 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDao.php,v 1.8 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -56,7 +56,7 @@ require_once 'SyL_DBSqlTableRelations.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDao.php,v 1.7 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDao.php,v 1.8 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBDao
@@ -514,6 +514,27 @@ class SyL_DBDao
         return $this->error_messages;
     }
 
+    /**
+     * ޼֥Ȥ
+     *
+     * @access public
+     * @return object ޼֥
+     */
+    function &getSchema()
+    {
+        return $this->conn->getSchema();
+    }
+
+    /**
+     * ³֥Ȥ
+     *
+     * @access public
+     * @return object ³֥
+     */
+    function &getConnection()
+    {
+        return $this->conn;
+    }
 }
 
 ?>
