@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.2 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.3 2007/10/15 13:56:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ SyL_Loader::lib('File');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.2 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.3 2007/10/15 13:56:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Index extends AppAction
@@ -342,14 +342,17 @@ class Index extends AppAction
             // ʸ
             $name = strtoupper($name);
             // ơ֥
-            $columns[$name]  = '';
+            $columns[$name] = array(
+              'type'     => $column['type'],
+              'validate' => $this->getValidateDefinition($column)
+            );
             // ե
             $elements[$name] = array(
               'alias'       => $maintenance_table,
               'type'        => 'text',
               'name'        => $name,
               'attributes'  => array('size' => '30'),
-              'validate'    => $this->getValidateDefinition($column),
+              'validate'    => array(),
               'sort_list'   => $i,
               'sort_detail' => $i
             );
@@ -432,6 +435,9 @@ class Index extends AppAction
             // ǥ쥯ȥ
             $form_opp_search[]  = '{ACTION_DIR}';
             $form_opp_replace[] = (count($action_names) > 0) ? implode('_', $action_names) . '_' : '';
+            // ƥץ졼ȥǥ쥯ȥ
+            $form_opp_search[]  = '{TEMPLATE_DIR}';
+            $form_opp_replace[] = (count($action_names) > 0) ? implode('/', $action_names) . '/' : '';
             // ե९饹̾
             $form_opp_search[]  = '{FORM_CLASS_NAME}';
             $form_opp_replace[] = SyL_Loader::convertClass($form_class);
@@ -477,6 +483,14 @@ class Index extends AppAction
 
         if ($action_name) {
             // ե
+            $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Index.php';
+            $create_file   = "{$action_dir}/" . basename($template_file);
+            $cmd->stdout("  action template file {$template_file}"); ob_flush();
+            $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
+
+            $file =& SyL_File::factory('w', $create_file);
+            $file->process(str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
+
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Lst.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
             $cmd->stdout("  action template file {$template_file}"); ob_flush();
